import { TextProps, StyleProp, ViewStyle, ViewProps, TouchableOpacityProps } from 'react-native';

type IBoldProps = {
    fontFamily?: string;
} & TextProps;

declare const Bold: ({ fontFamily, children }: IBoldProps) => JSX.Element;

type ICodeProps = TextProps;

declare const Code: ({ children }: ICodeProps) => JSX.Element;

/** Reference https://github.com/editor-js/delimiter */
type IDelimiterProps = {
    data: Record<string, never>;
    containerStyle?: StyleProp<ViewStyle>;
} & Omit<ViewProps, 'style'>;

/** Reference https://github.com/editor-js/delimiter */
declare const Delimiter: ({ containerStyle, ...rest }: IDelimiterProps) => JSX.Element;

type IFallbackBlockProps = {
    blockType: string;
    containerStyle?: StyleProp<ViewStyle>;
} & Omit<ViewProps, 'style'>;

declare const FallbackBlock: ({ blockType, containerStyle, ...rest }: IFallbackBlockProps) => JSX.Element;

type IHeaderProps = {
    data: {
        level: 1 | 2 | 3 | 4 | 5 | 6;
        text: string;
    };
    fontFamily?: string;
} & TextProps;

declare const Header: ({ data, fontFamily, style, ...rest }: IHeaderProps) => JSX.Element;

type IImageFrameProps = {
    data: {
        file: {
            url: string;
        };
        caption?: string;
        withBorder?: boolean;
        withBackground?: boolean;
        stretched?: boolean;
    };
    captionFontFamily?: string;
    containerStyle?: StyleProp<ViewStyle>;
} & Omit<ViewProps, 'style'>;

declare const ImageFrame: ({ data, captionFontFamily, containerStyle, ...rest }: IImageFrameProps) => JSX.Element;

type IItalicProps = {
    fontFamily?: string;
} & TextProps;

declare const Italic: ({ children, fontFamily }: IItalicProps) => JSX.Element;

type ILinkToolProps = {
    data: {
        link: string;
        meta: {
            title?: string;
            site_name?: string;
            description?: string;
            image?: {
                url?: string;
            };
        };
    };
    containerStyle?: StyleProp<ViewStyle>;
} & Omit<TouchableOpacityProps, 'style'>;

declare const LinkTool: ({ data, containerStyle, ...rest }: ILinkToolProps) => JSX.Element;

type IListProps = {
    data: {
        items: Array<string>;
        style: 'ordered' | 'unordered';
    };
    fontFamily?: string;
    containerStyle?: StyleProp<ViewStyle>;
} & Omit<ViewProps, 'style'>;

declare const List: ({ data, fontFamily, containerStyle }: IListProps) => JSX.Element;

type IMarkProps = TextProps;

declare const Mark: ({ children }: IMarkProps) => JSX.Element;

type IParagraphProps = {
    data: {
        text: string;
    };
    fontFamily?: string;
} & TextProps;

declare const Paragraph: ({ data, fontFamily, style, ...rest }: IParagraphProps) => JSX.Element;

type IPersonalityProps = {
    data: {
        name?: string;
        description?: string;
        link: string;
        photo?: string;
    };
    containerStyle?: StyleProp<ViewStyle>;
} & Omit<TouchableOpacityProps, 'style'>;

declare const Personality: ({ data, containerStyle, ...rest }: IPersonalityProps) => JSX.Element;

type IQuoteProps = {
    data: {
        text: string;
        caption?: string;
        alignment?: 'left' | 'center';
    };
    quoteFontFamily?: string;
    captionFontFamily?: string;
    containerStyle?: StyleProp<ViewStyle>;
} & Omit<ViewProps, 'style'>;

declare const Quote: ({ data, quoteFontFamily, captionFontFamily, containerStyle, ...rest }: IQuoteProps) => JSX.Element;

type ISimpleImageProps = {
    data: {
        url: string;
        caption?: string;
        withBorder?: boolean;
        withBackground?: boolean;
        stretched?: boolean;
    };
    captionFontFamily?: string;
    containerStyle?: StyleProp<ViewStyle>;
} & Omit<TextProps, 'style'>;

declare const SimpleImage: ({ data, captionFontFamily, containerStyle, ...rest }: ISimpleImageProps) => JSX.Element;

type IUnderlineProps = {
    fontFamily?: string;
} & TextProps;

declare const Underline: ({ fontFamily, children }: IUnderlineProps) => JSX.Element;

export { Bold, Code, Delimiter, FallbackBlock, Header, IBoldProps, ICodeProps, IDelimiterProps, IFallbackBlockProps, IHeaderProps, IImageFrameProps, IItalicProps, ILinkToolProps, IListProps, IMarkProps, IParagraphProps, IPersonalityProps, IQuoteProps, ISimpleImageProps, IUnderlineProps, ImageFrame, Italic, LinkTool, List, Mark, Paragraph, Personality, Quote, SimpleImage, Underline };
